; Title - Bank Test
; By    - Adam Trionfo
; Rev   - 1.12 - Sept. 1, 2011
;         1.11 - Aug 30, 2011
;         1.0  - Aug 29, 2011
; 
; About this Program
; ------------------ 
;
; This program requires the Atarimax Maxflash Astrocade cartridge 
; to work.  This program will NOT work properly as a regular cartridge.
;
; "Bank test" will assemble as a 4K program.  In order to create the 
; proper 256K file with the required string in the correct location,
; the batch file "256kcart.bat" must be run (it is included in the
; archive).  The batch file will automatically create the 256K file 
; that is for use with the Maxflash cartridge.  The output of the 
; batch file, "256kprog.bin" is the file that needs to be programmed 
; onto the flash cart.  For convience, a pre-made "256kprog.bin" is
; included with the archive. 
; 
; "Bank Test" displays a short string, depending on if Bank 32
; of the Maxflash cartridge has been properly bankswitched to be
; in the Astrocade memory area $3000-$3FFF.  If $3000 contains a "B" 
; as the first byte then the bank switched correctly, and this
; program will display:
;     $3000 = 'B'
; If the program does not display that message, and it diplays this
; one instead, 
;     $3000 NOT = 'B'
; then something is not working properly.
;
; To assemble this Z-80 source code using ZMAC:
;  
; zmac -i -m -o banktest.bin -x banktest.lst banktest.asm

INCLUDE "HVGLIB.H"

        ORG    $2000    ; First byte of Cartridge
        DB     "U"      ; User System Sentinel

        DW     MENUST   ; Next menu link
        DW     PRGNAM   ; Address of title for program
        DW     PRGST    ; Jump here if prog is selected

; Main Program
PRGST:  DI
        SYSTEM (INTPC)

        DO     (SETOUT)
        DB     $B0        ; Vertical Blanking Line
        DB     $2C        ; Left/Right Color Boundary
        DB     $08        ; Interrupt Mode
 
        DO     (COLSET)
        DW     COLTAB     ; Color Table

        DO     (FILL)
        DW     NORMEM     ; Destination
        DW     4000D      ; Bytes to move
        DB     $00        ; Background color

        EXIT

        LD     A,($3FC0+32)  ; Switch to Bank 32 (No affect in MESS)
                             ; Bank 32, $20000-$20FFF        

        LD     A,($3000)   ; Load A with first byte of Bank 0

        CP     'B'         ; Is byte $3000 a 'B' ($42)?
        JP     Z,GOOD      ; If $3000='B' then Print 

        SYSSUK STRDIS     ; The Byte was Bad
        DB     0          ; X coordinate
        DB     0          ; Y coordinate
        DB     $0C        ; Options
        DW     BADBYT     ; String to Display        

        JP     LOOP
        
GOOD:   SYSSUK STRDIS     ; The Byte was Good
        DB     0          ; X coordinate
        DB     0          ; Y coordinate
        DB     $0C        ; Options
        DW     GODBYT     ; String to Display        

LOOP:  NOP
       JP     LOOP       ; Infinite loop

; Color Table #1
COLTAB: DB     $00        ; Color 3 Left  - Black
        DB     $5A        ; Color 2 Left  - Red
        DB     $77        ; Color 1 Left  - Yellow
        DB     $07        ; Color 0 Left  - White
        DB     $00        ; Color 3 Right - Black
        DB     $5A        ; Color 2 Right - Red
        DB     $77        ; Color 1 Right - Yellow
        DB     $07        ; Color 0 Right - White


PRGNAM: DB     "BANK TEST"
        DB     $00        ; End String

BADBYT: DB     "$3000 NOT = 'B'"
        DB     $00        ; End String

GODBYT: DB     "$3000 = 'B'"
        DB     $00        ; End String

; The following is left in the program in case you want to experiment
; with this program under emulation using 8K on contiguous space. 

;        ORG    $3000

;L3000:  DB     "BANK 000" ; $3000 = B
;        DB     $00        ; End String

;L3000:  DB     "0ANK 000"  ; Make $3000 NOT = B
;        DB     $00        ; End String
        
        ORG    $2FFF

        DB     $00        ; Last byte of ROM
      